@@ -2,7 +2,7 @@ package Mojolicious::Plugin::SimpleSlides;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 use File::Spec;
@@ -72,7 +72,7 @@ sub register {
     shift->tag('pre' => class => 'code-line' => @_);
   });
 
-  $app->routes->any(
+  $app->routes->any( 
     '/:slide',
     { slide => $plugin->first_slide },
     [ slide => qr/\b\d+\b/ ],
@@ -103,15 +103,15 @@ sub next_slide {
 sub _action {
   my $c = shift;
   my $plugin = $c->simple_slides;
-  my $slide = $plugin->template_for_slide($c->stash( 'slide' ))
-    or return $c->render_not_found;
+  my $slide = $plugin->template_for_slide($c->stash( 'slide' )) 
+    or return $c->reply->not_found;
   $c->layout( $plugin->layout );
-  $c->render( $slide ) || $c->render_not_found;
+  $c->render( $slide ) || $c->reply->not_found;
 }
 
 # helpers
 
-sub _column {
+sub _column { 
   my $c = shift;
   my $plugin = $c->simple_slides;
   my $content = pop || return;
@@ -128,19 +128,21 @@ sub _column {
   if ( my $align = delete $args{align} || $plugin->column_align ) {
     $style .= "vertical-align: $align;";
   }
-
-  return $c->include(
+ 
+  return $c->render( 
+    partial => 1, 
     'columns.style' => $style,
-    'columns.column' => $content,
+    'columns.column' => $content, 
     template => $plugin->column_template,
   );
 }
 
-sub _columns {
+sub _columns { 
   my $c = shift;
   return unless @_;
   my $content = shift->();
-  return $c->include(
+  return $c->render( 
+    partial => 1, 
     'columns.content' => $content,
     template => $c->simple_slides->columns_template,
   );
@@ -152,7 +154,7 @@ __DATA__
 
 @@ simple_slides_column.html.ep
 % my @tag = qw/div class column/;
-% if ( my $style = stash 'columns.style' ) { push @tag, style => $style }
+% if ( my $style = stash 'columns.style' ) { push @tag, style => $style } 
 %= tag @tag, begin
   %= stash 'columns.column'
 % end
@@ -172,8 +174,9 @@ __DATA__
     % if ( my $href = simple_slides->base_href ) {
       %= tag base => href => $href
     % }
-    % if ( my $ppi_css = __PACKAGE__->can('ppi_css') ) {
-      %= $ppi_css->();
+    % if ( __PACKAGE__->can('ppi') ) {
+      %= stylesheet '/ppi.css';
+      %= javascript '/ppi.js';
     % }
     %= stylesheet '/simple_slides.css'
     %= javascript '/mousetrap.min.js'
